@@ -6,7 +6,7 @@
   SPDX-FileCopyrightText: 2004 Cornelius Schumacher <schumacher@kde.org>
   SPDX-FileCopyrightText: 2004 Reinhold Kainhofer <reinhold@kainhofer.com>
   SPDX-FileCopyrightText: 2005 Rafal Rzepecki <divide@users.sourceforge.net>
-  SPDX-FileCopyrightText: 2010-2024 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2010-2025 Laurent Montel <montel@kde.org>
   SPDX-FileCopyrightText: 2012-2019 Allen Winter <winter@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
@@ -747,10 +747,11 @@ void ActionManager::initActions()
     mShowMenuBarAction->setChecked(KOPrefs::instance()->showMenuBar());
     toggleMenubar(true);
 
+#if !defined(Q_OS_WIN) && !defined(Q_OS_MACOS)
     action = new QAction(i18nc("@action", "Configure &Date && Time…"), this);
     mACollection->addAction(QStringLiteral("conf_datetime"), action);
     connect(action, &QAction::triggered, this, &ActionManager::configureDateTime);
-
+#endif
     action = new QAction(QIcon::fromTheme(QStringLiteral("view-filter")), i18n("Manage View &Filters…"), this);
     mACollection->addAction(QStringLiteral("edit_filters"), action);
     connect(action, &QAction::triggered, mCalendarView, &CalendarView::editFilters);
@@ -973,7 +974,7 @@ bool ActionManager::importURL(const QUrl &url, bool merge)
     } else {
         // empty error message means user canceled.
         if (!importer->errorMessage().isEmpty()) {
-            mCalendarView->showMessage(i18n("An error occurred: %1", importer->errorMessage()), KMessageWidget::Error);
+            mCalendarView->showMessage(i18n("An error occurred: %1 (url: %2)", importer->errorMessage(), url.path()), KMessageWidget::Error);
         }
     }
 
